@@ -326,6 +326,8 @@ void reload_history(gint from_index = -1);
 extern "C" {
 #endif
 
+gboolean on_math_entry_key_press_event(GtkWidget *o, GdkEventKey *event, gpointer);
+
 void hide_tooltip(GtkWidget*);
 
 void on_tShortcuts_selection_changed(GtkTreeSelection *treeselection, gpointer user_data);
@@ -853,8 +855,6 @@ void on_units_convert_search_changed(GtkEntry *w, gpointer user_data);
 void on_functions_entry_search_changed(GtkEntry *w, gpointer user_data);
 void on_variables_entry_search_changed(GtkEntry *w, gpointer user_data);
 
-void save_accels();
-
 gboolean on_menu_key_press(GtkWidget *widget, GdkEventKey *event);
 
 #ifdef __cplusplus
