@@ -31,6 +31,7 @@ using std::vector;
 using std::endl;
 
 MathStructure *mstruct, *matrix_mstruct, *parsed_mstruct, *parsed_tostruct, *displayed_mstruct;
+extern MathStructure mbak_convert;
 string *parsed_to_str;
 KnownVariable *vans[5];
 GtkWidget *functions_window;
@@ -86,6 +87,47 @@ static GOptionEntry options[] = {
 	{NULL}
 };
 
+void block_completion();
+void unblock_completion();
+
+gboolean create_menus_etc(gpointer) {
+
+	//create button menus after definitions have been loaded
+	create_button_menus();
+
+	//create dynamic menus
+	generate_units_tree_struct();
+
+	update_unit_selector_tree();
+
+	generate_functions_tree_struct();
+	generate_variables_tree_struct();
+	create_fmenu();
+	create_vmenu();
+	create_umenu();
+	create_umenu2();
+	create_pmenu2();
+
+	for(int i = ((int) recent_functions_pre.size()) - 1; i >= 0; i--) {
+		function_inserted(CALCULATOR->getActiveFunction(recent_functions_pre[i]));
+	}
+	for(int i = ((int) recent_variables_pre.size()) - 1; i >= 0; i--) {
+		variable_inserted(CALCULATOR->getActiveVariable(recent_variables_pre[i]));
+	}
+	for(int i = ((int) recent_units_pre.size()) - 1; i >= 0; i--) {
+		Unit *u = CALCULATOR->getActiveUnit(recent_units_pre[i]);
+		if(!u) u = CALCULATOR->getCompositeUnit(recent_units_pre[i]);
+		unit_inserted(u);
+	}
+
+	update_completion();
+	
+	unblock_completion();
+	
+	return FALSE;
+
+}
+
 void create_application(GtkApplication *app) {
 
 #if GTK_MAJOR_VERSION > 3 || GTK_MINOR_VERSION >= 14
@@ -121,8 +163,8 @@ void create_application(GtkApplication *app) {
 	parsed_tostruct->setUndefined();
 	matrix_mstruct = new MathStructure();
 	parsed_to_str = new string;
+	mbak_convert.setUndefined();
 
-	bool canplot = CALCULATOR->canPlot();
 	bool canfetch = CALCULATOR->canFetch();
 
 	//create main window
@@ -226,39 +268,8 @@ void create_application(GtkApplication *app) {
 	check_expression_position = true;
 	expression_position = 1;
 
-	gtk_widget_set_sensitive(GTK_WIDGET(gtk_builder_get_object (main_builder, "menu_item_plot_functions")), canplot);
 	gtk_widget_set_sensitive(GTK_WIDGET(gtk_builder_get_object (main_builder, "menu_item_fetch_exchange_rates")), canfetch);
 
-	//create button menus after definitions have been loaded
-	create_button_menus();
-
-	//create dynamic menus
-	generate_units_tree_struct();
-
-	generate_functions_tree_struct();
-	generate_variables_tree_struct();
-	create_fmenu();
-	create_vmenu();
-	create_umenu();
-	create_umenu2();
-	create_pmenu2();
-
-	update_unit_selector_tree();
-
-	for(int i = ((int) recent_functions_pre.size()) - 1; i >= 0; i--) {
-		function_inserted(CALCULATOR->getActiveFunction(recent_functions_pre[i]));
-	}
-	for(int i = ((int) recent_variables_pre.size()) - 1; i >= 0; i--) {
-		variable_inserted(CALCULATOR->getActiveVariable(recent_variables_pre[i]));
-	}
-	for(int i = ((int) recent_units_pre.size()) - 1; i >= 0; i--) {
-		Unit *u = CALCULATOR->getActiveUnit(recent_units_pre[i]);
-		if(!u) u = CALCULATOR->getCompositeUnit(recent_units_pre[i]);
-		unit_inserted(u);
-	}
-
-	update_completion();
-
 	view_thread = new ViewThread;
 	view_thread->start();
 	command_thread = new CommandThread;
@@ -274,25 +285,16 @@ void create_application(GtkApplication *app) {
 	}
 	gtk_widget_queue_draw(resultview);
 
-	gchar *gstr = g_build_filename(getLocalDir().c_str(), "accelmap", NULL);
-#ifndef _WIN32
-	if(!fileExists(gstr)) {
-		g_free(gstr);
-		gstr = g_build_filename(getOldLocalDir().c_str(), "accelmap", NULL);
-		gtk_accel_map_load(gstr);
-		g_remove(gstr);
-		g_rmdir(getOldLocalDir().c_str());
-		g_free(gstr);
-		return;
-	}
-#endif
-	gtk_accel_map_load(gstr);
-	g_free(gstr);
+	block_completion();
+	set_custom_buttons();
+	g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE, 50, create_menus_etc, NULL, NULL);
 
 	if(check_version) {
 		QalculateDateTime next_version_check_date(last_version_check_date);
 		next_version_check_date.addDays(14);
-		if(!next_version_check_date.isFutureDate()) g_idle_add(on_check_version_idle, NULL);
+		if(!next_version_check_date.isFutureDate()) {
+			g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE, 50, on_check_version_idle, NULL, NULL);
+		}
 	}
 
 }
