@@ -105,11 +105,33 @@ bool has_error() {
 
 static void qalculate_search_provider_activate_result(ShellSearchProvider2 *object, GDBusMethodInvocation *invocation, gchar *result, gchar **terms, guint timestamp, gpointer user_data) {
 	gchar *joined_terms = g_strjoinv(" ", terms);
-	string str = "qalculate-gtk \"";
-	str += joined_terms;
-	str += "\"";
+	if(strcmp(result, "copy-to-clipboard") == 0) {
+		unordered_map<string, string>::const_iterator it = expressions.find(joined_terms);
+		if(it != expressions.end()) {
+			it = results.find(it->second);
+			if(it != expressions.end()) {
+				size_t i = string::npos;
+				if(search_po.use_unicode_signs) {
+					i = it->second.find(SIGN_ALMOST_EQUAL " ");
+					if(i == 0) i = strlen(SIGN_ALMOST_EQUAL) - 1;
+					else i = string::npos;
+				} else {
+					i = it->second.find(_("approx."));
+					if(i == 0) i = strlen(_("approx.")) - 1;
+					else i = string::npos;
+				}
+				if(i == string::npos) i = it->second.find("= ");
+				if(i != string::npos) i += 2;
+				gtk_clipboard_set_text(gtk_clipboard_get(gdk_atom_intern("CLIPBOARD", FALSE)), i == string::npos ? it->second.c_str() : it->second.substr(i).c_str(), -1);
+			}
+		}
+	} else {
+		string str = "qalculate-gtk \"";
+		str += joined_terms;
+		str += "\"";
+		g_spawn_command_line_async(str.c_str(), NULL);
+	}
 	g_free(joined_terms);
-	g_spawn_command_line_async(str.c_str(), NULL);
 	g_dbus_method_invocation_return_value(invocation, NULL);
 }
 void handle_terms(gchar *joined_terms, GVariantBuilder &builder) {
@@ -121,6 +143,7 @@ void handle_terms(gchar *joined_terms, GVariantBuilder &builder) {
 	if(it != expressions.end()) {
 		if(it->second.empty()) return;
 		g_variant_builder_add(&builder, "s", expression.c_str());
+		if(results.find(it->second) != results.end() && !it->second.empty()) g_variant_builder_add(&builder, "s", "copy-to-clipboard");
 	} else {
 		bool b_valid = false;
 		expressions[expression] = "";
@@ -159,6 +182,7 @@ void handle_terms(gchar *joined_terms, GVariantBuilder &builder) {
 			result = "";
 		}
 		expressions[expression] = parsed;
+		g_variant_builder_add(&builder, "s", expression.c_str());
 		if(parsed.empty() || result == parsed) {
 			results[result] = "";
 		} else {
@@ -173,10 +197,10 @@ void handle_terms(gchar *joined_terms, GVariantBuilder &builder) {
 				} else {
 					result.insert(0, "= ");
 				}
+				g_variant_builder_add(&builder, "s", "copy-to-clipboard");
 			}
 			results[parsed] = result;
 		}
-		g_variant_builder_add(&builder, "s", expression.c_str());
 	}
 }
 static void qalculate_search_provider_get_initial_result_set(ShellSearchProvider2 *object, GDBusMethodInvocation *invocation, gchar **terms, gpointer user_data) {
@@ -188,18 +212,28 @@ static void qalculate_search_provider_get_initial_result_set(ShellSearchProvider
 }
 static void qalculate_search_provider_get_result_metas(ShellSearchProvider2 *object, GDBusMethodInvocation *invocation, gchar **eqs, gpointer user_data) {
 	gint idx;
-	GVariantBuilder meta, metas;
-	g_variant_builder_init (&metas, G_VARIANT_TYPE ("aa{sv}"));
+	GVariantBuilder metas;
+	g_variant_builder_init(&metas, G_VARIANT_TYPE ("aa{sv}"));
 	for(idx = 0; eqs[idx] != NULL; idx++) {
-		unordered_map<string, string>::const_iterator it = expressions.find(eqs[idx]);
-		if(it != expressions.end()) {
-			g_variant_builder_init(&meta, G_VARIANT_TYPE ("a{sv}"));
-			g_variant_builder_add(&meta, "{sv}", "id", g_variant_new_string(eqs[idx]));
-			g_variant_builder_add(&meta, "{sv}", "name", g_variant_new_string(it->second.c_str()));
-			it = results.find(it->second);
-			if(it != results.end() && !it->second.empty()) {
-				g_variant_builder_add(&meta, "{sv}", "description", g_variant_new_string(it->second.c_str()));
+		if(strcmp(eqs[idx], "copy-to-clipboard") != 0) {
+			unordered_map<string, string>::const_iterator it = expressions.find(eqs[idx]);
+			if(it != expressions.end()) {
+				GVariantBuilder meta;
+				g_variant_builder_init(&meta, G_VARIANT_TYPE("a{sv}"));
+				g_variant_builder_add(&meta, "{sv}", "id", g_variant_new_string(eqs[idx]));
+				g_variant_builder_add(&meta, "{sv}", "name", g_variant_new_string(it->second.c_str()));
+				it = results.find(it->second);
+				if(it != results.end() && !it->second.empty()) {
+					g_variant_builder_add(&meta, "{sv}", "description", g_variant_new_string(it->second.c_str()));
+				}
+				g_variant_builder_add_value(&metas, g_variant_builder_end(&meta));
 			}
+		} else {
+			GVariantBuilder meta;
+			g_variant_builder_init(&meta, G_VARIANT_TYPE("a{sv}"));
+			g_variant_builder_add(&meta, "{sv}", "id", g_variant_new_string("copy-to-clipboard"));
+			g_variant_builder_add(&meta, "{sv}", "name", g_variant_new_string(_("Copy")));
+			g_variant_builder_add(&meta, "{sv}", "description", g_variant_new_string(_("Copy result to clipboard")));
 			g_variant_builder_add_value(&metas, g_variant_builder_end(&meta));
 		}
 	}
